@@ -17,6 +17,7 @@ elif isosx:
 class PluginNotFound(ValueError):
     pass
 
+
 class InvalidPlugin(ValueError):
     pass
 
@@ -312,6 +313,7 @@ class Plugin(object):  # {{{
 
 # }}}
 
+
 class FileTypePlugin(Plugin):  # {{{
     '''
     A plugin that is associated with a particular set of file types.
@@ -347,7 +349,9 @@ class FileTypePlugin(Plugin):  # {{{
         modified ebook. If no modifications are needed, it should
         return the path to the original ebook. If an error is encountered
         it should raise an Exception. The default implementation
-        simply return the path to the original ebook.
+        simply return the path to the original ebook. Note that the path to
+        the original file (before any file type plugins are run, is available as
+        self.original_path_to_file).
 
         The modified ebook file should be created with the
         :meth:`temporary_file` method.
@@ -392,6 +396,7 @@ class FileTypePlugin(Plugin):  # {{{
 
 # }}}
 
+
 class MetadataReaderPlugin(Plugin):  # {{{
     '''
     A plugin that implements reading metadata from a set of file types.
@@ -422,6 +427,7 @@ class MetadataReaderPlugin(Plugin):  # {{{
         return None
 # }}}
 
+
 class MetadataWriterPlugin(Plugin):  # {{{
     '''
     A plugin that implements reading metadata from a set of file types.
@@ -453,6 +459,7 @@ class MetadataWriterPlugin(Plugin):  # {{{
 
 # }}}
 
+
 class CatalogPlugin(Plugin):  # {{{
     '''
     A plugin that implements a catalog generator.
@@ -580,6 +587,7 @@ class CatalogPlugin(Plugin):  # {{{
 
 # }}}
 
+
 class InterfaceActionBase(Plugin):  # {{{
 
     supported_platforms = ['windows', 'osx', 'linux']
@@ -607,6 +615,7 @@ class InterfaceActionBase(Plugin):  # {{{
 
 # }}}
 
+
 class PreferencesPlugin(Plugin):  # {{{
 
     '''
@@ -666,6 +675,7 @@ class PreferencesPlugin(Plugin):  # {{{
 
 # }}}
 
+
 class StoreBase(Plugin):  # {{{
 
     supported_platforms = ['windows', 'osx', 'linux']
@@ -715,6 +725,7 @@ class StoreBase(Plugin):  # {{{
 
 # }}}
 
+
 class ViewerPlugin(Plugin):  # {{{
 
     type = _('Viewer')
@@ -774,6 +785,7 @@ class ViewerPlugin(Plugin):  # {{{
 
 # }}}
 
+
 class EditBookToolPlugin(Plugin):  # {{{
 
     type = _('Edit Book Tool')
@@ -781,3 +793,25 @@ class EditBookToolPlugin(Plugin):  # {{{
 
 # }}}
 
+
+class LibraryClosedPlugin(Plugin):  # {{{
+    '''
+    LibraryClosedPlugins are run when a library is closed, either at shutdown,
+    when the library is changed, or when a library is used in some other way.
+    At the moment these plugins won't be called by the CLI functions.
+    '''
+    type = _('Library Closed')
+
+    # minimum version 2.54 because that is when support was added
+    minimum_calibre_version = (2, 54, 0)
+
+    def run(self, db):
+        '''
+        The db will be a reference to the new_api (db.cache.py).
+
+        The plugin must run to completion. It must not use the GUI, threads, or
+        any signals.
+        '''
+        raise NotImplementedError('LibraryClosedPlugin '
+                'run method must be overridden in subclass')
+# }}}
